@@ -184,7 +184,7 @@ from ae.i18n import default_language, get_f_string, register_package_translation
 from ae.gui_app import FLOW_KEY_SEP, flow_action, id_of_flow, module_globals, MainAppBase       # type: ignore
 
 
-__version__ = '0.1.23'
+__version__ = '0.1.24'
 
 
 register_package_translations()
@@ -337,14 +337,14 @@ class HelpAppBase(MainAppBase, ABC):
 
     # overwritten methods
 
-    def change_app_state(self, state_name: str, state_value: Any, send_event: bool = True):
+    def change_app_state(self, state_name: str, state_value: Any, send_event: bool = True, old_name: str = ''):
         """ change app state via :meth:`~ae.gui_app.MainAppBase.change_app_state`, show help text in active help mode.
 
         All parameters are documented in the overwritten method :meth:`~ae.gui_app.MainAppBase.change_app_state`.
         """
-        help_vars = dict(state_name=state_name, state_value=state_value, send_event=send_event)
+        help_vars = dict(state_name=state_name, state_value=state_value, send_event=send_event, old_name=old_name)
         if not self.help_app_state_display(help_vars):
-            super().change_app_state(state_name, state_value, send_event=send_event)
+            super().change_app_state(state_name, state_value, send_event=send_event, old_name=old_name)
             self.help_app_state_display(help_vars, changed=True)
 
     def change_flow(self, new_flow_id: str, **event_kwargs) -> bool:
